from django.db.models import Q
from django.utils.translation import gettext_lazy as _
from django_tables2.views import SingleTableView

from member.models import TFJMUser
from .models import Tournament
from .tables import TournamentTable


class TournamentListView(SingleTableView):
    model = Tournament
    table_class = TournamentTable
    extra_context = dict(title=_("Tournaments list"),)

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)

        team_users = TFJMUser.objects.filter(Q(team__isnull=False) | Q(role="admin") | Q(role="organizer"))
        valid_team_users = team_users.filter(Q(team__validation_status="valid") | Q(role="admin") | Q(role="organizer"))

        context["team_users_emails"] = [user.email for user in team_users]
        context["valid_team_users_emails"] = [user.email for user in valid_team_users]

        return context
